from servergrimoire.dispatcher import grimoire


def launcher():
    grimoire(prog_name="servergrimoire")


if __name__ == "__main__":
    launcher()
